@@ -27,7 +27,7 @@ import threading
 
 from oslo_config import cfg
 from oslo_db import exception as db_exception
-from oslo_db.sqlalchemy import session
+from oslo_db.sqlalchemy import session as oslo_db_session
 from oslo_log import log as logging
 from oslo_utils import excutils
 import osprofiler.sqlalchemy
@@ -82,7 +82,10 @@ def _create_facade_lazily():
     if _FACADE is None:
         with _LOCK:
             if _FACADE is None:
-                _FACADE = session.EngineFacade.from_config(CONF)
+                _FACADE = oslo_db_session.EngineFacade.from_config(
+                    CONF,
+                    sqlite_fk=True,
+                )
 
                 if CONF.profiler.enabled and CONF.profiler.trace_sqlalchemy:
                     osprofiler.sqlalchemy.add_tracing(sqlalchemy,
@@ -412,17 +415,17 @@ def _paginate_query(query, model, limit, sort_keys, marker=None,
                 model_attr = getattr(model, sort_keys[j])
                 default = _get_default_column_value(
                     model_attr.property.columns[0].type)
-                attr = sa_sql.expression.case([(model_attr != None,
-                                              model_attr), ],
-                                              else_=default)
+                attr = sa_sql.expression.case(
+                    (model_attr != None, model_attr),
+                    else_=default)
                 crit_attrs.append((attr == marker_values[j]))
 
             model_attr = getattr(model, sort_keys[i])
             default = _get_default_column_value(
                 model_attr.property.columns[0].type)
-            attr = sa_sql.expression.case([(model_attr != None,
-                                          model_attr), ],
-                                          else_=default)
+            attr = sa_sql.expression.case(
+                (model_attr != None, model_attr),
+                else_=default)
             if sort_dirs[i] == 'desc':
                 crit_attrs.append((attr < marker_values[i]))
             elif sort_dirs[i] == 'asc':
@@ -491,9 +494,10 @@ def _make_conditions_from_filters(filters, is_public=None):
     if 'tags' in filters:
         tags = filters.pop('tags')
         for tag in tags:
-            tag_filters = [models.ImageTag.deleted == False]
-            tag_filters.extend([models.ImageTag.value == tag])
-            tag_conditions.append(tag_filters)
+            alias = sa_orm.aliased(models.ImageTag)
+            tag_filters = [alias.deleted == False]
+            tag_filters.extend([alias.value == tag])
+            tag_conditions.append((alias, tag_filters))
 
     filters = {k: v for k, v in filters.items() if v is not None}
 
@@ -555,17 +559,18 @@ def _make_conditions_from_filters(filters, is_public=None):
 
 
 def _make_image_property_condition(key, value):
-    prop_filters = [models.ImageProperty.deleted == False]
-    prop_filters.extend([models.ImageProperty.name == key])
-    prop_filters.extend([models.ImageProperty.value == value])
-    return prop_filters
+    alias = sa_orm.aliased(models.ImageProperty)
+    prop_filters = [alias.deleted == False]
+    prop_filters.extend([alias.name == key])
+    prop_filters.extend([alias.value == value])
+    return alias, prop_filters
 
 
 def _select_images_query(context, image_conditions, admin_as_user,
                          member_status, visibility):
     session = get_session()
 
-    img_conditional_clause = sa_sql.and_(*image_conditions)
+    img_conditional_clause = sa_sql.and_(True, *image_conditions)
 
     regular_user = (not context.is_admin) or admin_as_user
 
@@ -673,14 +678,12 @@ def image_get_all(context, filters=None, marker=None, limit=None,
         query = query.filter(sa_sql.or_(*community_filters))
 
     if prop_cond:
-        for prop_condition in prop_cond:
-            query = query.join(models.ImageProperty, aliased=True).filter(
-                sa_sql.and_(*prop_condition))
+        for alias, prop_condition in prop_cond:
+            query = query.join(alias).filter(sa_sql.and_(*prop_condition))
 
     if tag_cond:
-        for tag_condition in tag_cond:
-            query = query.join(models.ImageTag, aliased=True).filter(
-                sa_sql.and_(*tag_condition))
+        for alias, tag_condition in tag_cond:
+            query = query.join(alias).filter(sa_sql.and_(*tag_condition))
 
     marker_image = None
     if marker is not None:
@@ -1494,7 +1497,8 @@ def purge_deleted_rows(context, age_in_days, max_rows, session=None):
     _validate_db_int(max_rows=max_rows)
 
     session = session or get_session()
-    metadata = MetaData(get_engine())
+    metadata = MetaData()
+    engine = get_engine()
     deleted_age = timeutils.utcnow() - datetime.timedelta(days=age_in_days)
 
     tables = []
@@ -1508,11 +1512,11 @@ def purge_deleted_rows(context, age_in_days, max_rows, session=None):
     # are referencing soft deleted tasks/images records (e.g. task_info
     # records). Then purge all soft deleted records in glance tables in the
     # right order to avoid FK constraint violation.
-    t = Table("tasks", metadata, autoload=True)
-    ti = Table("task_info", metadata, autoload=True)
+    t = Table("tasks", metadata, autoload_with=engine)
+    ti = Table("task_info", metadata, autoload_with=engine)
     joined_rec = ti.join(t, t.c.id == ti.c.task_id)
     deleted_task_info = sql.\
-        select([ti.c.task_id], t.c.deleted_at < deleted_age).\
+        select(ti.c.task_id).where(t.c.deleted_at < deleted_age).\
         select_from(joined_rec).\
         order_by(t.c.deleted_at)
     if max_rows != -1:
@@ -1551,7 +1555,7 @@ def purge_deleted_rows(context, age_in_days, max_rows, session=None):
             tables.append(tbl)
 
     for tbl in tables:
-        tab = Table(tbl, metadata, autoload=True)
+        tab = Table(tbl, metadata, autoload_with=engine)
         LOG.info(
             _LI('Purging deleted rows older than %(age_in_days)d day(s) '
                 'from table %(tbl)s'),
@@ -1560,7 +1564,8 @@ def purge_deleted_rows(context, age_in_days, max_rows, session=None):
         column = tab.c.id
         deleted_at_column = tab.c.deleted_at
 
-        query_delete = sql.select([column], deleted_at_column < deleted_age).\
+        query_delete = sql.select(column).\
+            where(deleted_at_column < deleted_age).\
             order_by(deleted_at_column)
         if max_rows != -1:
             query_delete = query_delete.limit(max_rows)
@@ -1592,11 +1597,12 @@ def purge_deleted_rows_from_images(context, age_in_days, max_rows,
     _validate_db_int(max_rows=max_rows)
 
     session = session or get_session()
-    metadata = MetaData(get_engine())
+    metadata = MetaData()
+    engine = get_engine()
     deleted_age = timeutils.utcnow() - datetime.timedelta(days=age_in_days)
 
     tbl = 'images'
-    tab = Table(tbl, metadata, autoload=True)
+    tab = Table(tbl, metadata, autoload_with=engine)
     LOG.info(
         _LI('Purging deleted rows older than %(age_in_days)d day(s) '
             'from table %(tbl)s'),
@@ -1606,7 +1612,8 @@ def purge_deleted_rows_from_images(context, age_in_days, max_rows,
     deleted_at_column = tab.c.deleted_at
 
     query_delete = sql.\
-        select([column], deleted_at_column < deleted_age).\
+        select(column).\
+        where(deleted_at_column < deleted_age).\
         order_by(deleted_at_column)
     if max_rows != -1:
         query_delete = query_delete.limit(max_rows)
@@ -1958,8 +1965,10 @@ def _task_format(task_ref, task_info_ref=None):
     return task_dict
 
 
-def metadef_namespace_get_all(context, marker=None, limit=None, sort_key=None,
-                              sort_dir=None, filters=None, session=None):
+def metadef_namespace_get_all(
+    context, marker=None, limit=None, sort_key='created_at',
+    sort_dir='desc', filters=None, session=None,
+):
     """List all available namespaces."""
     session = session or get_session()
     namespaces = metadef_namespace_api.get_all(
@@ -2037,12 +2046,12 @@ def metadef_object_delete(context, namespace_name, object_name,
         context, namespace_name, object_name, session)
 
 
-def metadef_object_delete_namespace_content(
-        context, namespace_name, session=None):
+def metadef_object_delete_namespace_content(context, namespace_name):
     """Delete an object or raise if namespace or object doesn't exist."""
-    session = session or get_session()
-    return metadef_object_api.delete_by_namespace_name(
-        context, namespace_name, session)
+    session = get_session()
+    with session.begin():
+        return metadef_object_api.delete_by_namespace_name(
+            context, namespace_name, session)
 
 
 def metadef_object_count(context, namespace_name, session=None):
@@ -2091,12 +2100,12 @@ def metadef_property_delete(context, namespace_name, property_name,
         context, namespace_name, property_name, session)
 
 
-def metadef_property_delete_namespace_content(
-        context, namespace_name, session=None):
+def metadef_property_delete_namespace_content(context, namespace_name):
     """Delete a property or raise if it or namespace doesn't exist."""
-    session = session or get_session()
-    return metadef_property_api.delete_by_namespace_name(
-        context, namespace_name, session)
+    session = get_session()
+    with session.begin():
+        return metadef_property_api.delete_by_namespace_name(
+            context, namespace_name, session)
 
 
 def metadef_property_count(context, namespace_name, session=None):
@@ -2161,8 +2170,9 @@ def metadef_resource_type_association_get_all_by_namespace(
 
 
 def metadef_tag_get_all(
-        context, namespace_name, filters=None, marker=None, limit=None,
-        sort_key=None, sort_dir=None, session=None):
+    context, namespace_name, filters=None, marker=None, limit=None,
+    sort_key='created_at', sort_dir='desc', session=None,
+):
     """Get metadata-schema tags or raise if none exist."""
     session = session or get_session()
     return metadef_tag_api.get_all(
@@ -2211,12 +2221,12 @@ def metadef_tag_delete(context, namespace_name, name,
         context, namespace_name, name, session)
 
 
-def metadef_tag_delete_namespace_content(
-        context, namespace_name, session=None):
+def metadef_tag_delete_namespace_content(context, namespace_name):
     """Delete an tag or raise if namespace or tag doesn't exist."""
-    session = session or get_session()
-    return metadef_tag_api.delete_by_namespace_name(
-        context, namespace_name, session)
+    session = get_session()
+    with session.begin():
+        return metadef_tag_api.delete_by_namespace_name(
+            context, namespace_name, session)
 
 
 def metadef_tag_count(context, namespace_name, session=None):
