@@ -27,10 +27,10 @@ from sqlalchemy import Boolean
 from sqlalchemy import Column
 from sqlalchemy import DateTime
 from sqlalchemy import Enum
-from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy import ForeignKey
 from sqlalchemy import Index
 from sqlalchemy import Integer
+from sqlalchemy.orm import declarative_base
 from sqlalchemy.orm import backref, relationship
 from sqlalchemy import sql
 from sqlalchemy import String
