@@ -13,18 +13,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
+import http.client as http
 import time
 
 from oslo_serialization import jsonutils
 from oslo_utils import timeutils
 import requests
-from six.moves import http_client as http
 
 
 def verify_image_hashes_and_status(
         test_obj, image_id, checksum=None, os_hash_value=None, status=None,
-        os_hash_algo='sha512'):
+        os_hash_algo='sha512', size=None):
     """Makes image-detail request and checks response.
 
     :param test_obj: The test object; expected to have _url() and
@@ -43,10 +42,10 @@ def verify_image_hashes_and_status(
     test_obj.assertEqual(checksum, image['checksum'])
     if os_hash_value:
         # make sure we're using the hashing_algorithm we expect
-        test_obj.assertEqual(six.text_type(os_hash_algo),
-                             image['os_hash_algo'])
+        test_obj.assertEqual(str(os_hash_algo), image['os_hash_algo'])
     test_obj.assertEqual(os_hash_value, image['os_hash_value'])
     test_obj.assertEqual(status, image['status'])
+    test_obj.assertEqual(size, image['size'])
 
 
 def wait_for_status(request_path, request_headers, status='active',
