@@ -18,7 +18,6 @@ import shutil
 
 import fixtures
 import oslo_middleware
-from oslotest import moxstubout
 
 from glance.api.middleware import context
 from glance.common import config
@@ -29,8 +28,6 @@ class TestPasteApp(test_utils.BaseTestCase):
 
     def setUp(self):
         super(TestPasteApp, self).setUp()
-        mox_fixture = self.useFixture(moxstubout.MoxStubout())
-        self.stubs = mox_fixture.stubs
 
     def _do_test_load_paste_app(self,
                                 expected_app_type,
@@ -64,15 +61,15 @@ class TestPasteApp(test_utils.BaseTestCase):
         paste_to = temp_file.replace('.conf', '-paste.ini')
         if not paste_config_file and make_paste_file:
             paste_from = os.path.join(os.getcwd(),
-                                      'etc/glance-registry-paste.ini')
+                                      'etc/glance-api-paste.ini')
             _appendto(paste_from, paste_to, paste_append)
 
-        app = config.load_paste_app('glance-registry')
+        app = config.load_paste_app('glance-api')
 
-        self.assertIsInstance(app, expected_app_type)
+        self.assertIsInstance(app['/'], expected_app_type)
 
     def test_load_paste_app(self):
-        expected_middleware = oslo_middleware.Healthcheck
+        expected_middleware = oslo_middleware.CORS
         self._do_test_load_paste_app(expected_middleware)
 
     def test_load_paste_app_paste_config_not_found(self):
@@ -81,8 +78,12 @@ class TestPasteApp(test_utils.BaseTestCase):
                           expected_middleware, make_paste_file=False)
 
     def test_load_paste_app_with_paste_flavor(self):
-        pipeline = ('[pipeline:glance-registry-incomplete]\n'
-                    'pipeline = context registryapp')
+        pipeline = ('[composite:glance-api-incomplete]\n'
+                    'paste.composite_factory = glance.api:root_app_factory\n'
+                    '/: api-incomplete\n'
+                    '/healthcheck: healthcheck\n'
+                    '[pipeline:api-incomplete]\n'
+                    'pipeline = context rootapp')
         expected_middleware = context.ContextMiddleware
         self._do_test_load_paste_app(expected_middleware,
                                      paste_flavor='incomplete',
@@ -90,11 +91,18 @@ class TestPasteApp(test_utils.BaseTestCase):
 
     def test_load_paste_app_with_paste_config_file(self):
         paste_config_file = os.path.join(os.getcwd(),
-                                         'etc/glance-registry-paste.ini')
-        expected_middleware = oslo_middleware.Healthcheck
+                                         'etc/glance-api-paste.ini')
+        expected_middleware = oslo_middleware.CORS
         self._do_test_load_paste_app(expected_middleware,
                                      paste_config_file=paste_config_file)
 
+    def test_load_paste_app_with_paste_config_file_but_not_exist(self):
+        paste_config_file = os.path.abspath("glance-api-paste.ini")
+        expected_middleware = oslo_middleware.Healthcheck
+        self.assertRaises(RuntimeError, self._do_test_load_paste_app,
+                          expected_middleware,
+                          paste_config_file=paste_config_file)
+
     def test_get_path_non_exist(self):
         self.assertRaises(RuntimeError, config._get_deployment_config_file)
 
