@@ -22,7 +22,6 @@ import os
 import socket
 from unittest import mock
 
-from babel import localedata
 import eventlet.patcher
 import fixtures
 from oslo_concurrency import processutils
@@ -45,13 +44,6 @@ class RequestTest(test_utils.BaseTestCase):
         if all_locales is None:
             all_locales = []
 
-        # Override localedata.locale_identifiers to return some locales.
-        def returns_some_locales(*args, **kwargs):
-            return all_locales
-
-        self.mock_object(localedata, 'locale_identifiers',
-                         returns_some_locales)
-
         # Override gettext.find to return other than None for some languages.
         def fake_gettext_find(lang_id, *args, **kwargs):
             found_ret = '/glance/%s/LC_MESSAGES/glance.mo' % lang_id
@@ -309,6 +301,19 @@ class ResourceTest(test_utils.BaseTestCase):
         self.assertRaises(AttributeError, resource.dispatch, Controller(),
                           'index', 'on', pants='off')
 
+    def test_dispatch_raises_bad_request(self):
+        class FakeController(object):
+            def index(self, shirt, pants=None):
+                return (shirt, pants)
+        resource = wsgi.Resource(FakeController(), None, None)
+
+        def dispatch(self, obj, action, *args, **kwargs):
+            raise exception.InvalidPropertyProtectionConfiguration()
+        self.mock_object(wsgi.Resource, 'dispatch', dispatch)
+        request = wsgi.Request.blank('/')
+        self.assertRaises(webob.exc.HTTPBadRequest, resource.__call__,
+                          request)
+
     def test_call(self):
         class FakeController(object):
             def index(self, shirt, pants=None):
@@ -388,8 +393,8 @@ class ResourceTest(test_utils.BaseTestCase):
     def test_response_headers_encoded(self):
         # prepare environment
         for_openstack_comrades = (
-            u'\u0417\u0430 \u043e\u043f\u0435\u043d\u0441\u0442\u0435\u043a, '
-            u'\u0442\u043e\u0432\u0430\u0440\u0438\u0449\u0438')
+            '\u0417\u0430 \u043e\u043f\u0435\u043d\u0441\u0442\u0435\u043a, '
+            '\u0442\u043e\u0432\u0430\u0440\u0438\u0449\u0438')
 
         class FakeController(object):
             def index(self, shirt, pants=None):
@@ -632,6 +637,30 @@ class ServerTest(test_utils.BaseTestCase):
             self.assertEqual(expected_workers,
                              len(server.children))
 
+    def test_invalid_staging_uri(self):
+        self.config(node_staging_uri='http://good.luck')
+        server = wsgi.Server()
+        with mock.patch.object(server, 'start_wsgi'):
+            # Make sure a stating URI with an bad scheme will abort startup
+            self.assertRaises(exception.GlanceException,
+                              server.start, 'fake-application', 34567)
+
+    @mock.patch('os.path.exists')
+    def test_missing_staging_dir(self, mock_exists):
+        mock_exists.return_value = False
+        server = wsgi.Server()
+        with mock.patch.object(server, 'start_wsgi'):
+            # Since we are mocking out start_wsgi, create a fake pool ourselves
+            server.pool = mock.MagicMock()
+            with mock.patch.object(wsgi, 'LOG') as mock_log:
+                server.start('fake-application', 34567)
+                mock_exists.assert_called_once_with('/tmp/staging/')
+                # Make sure a missing staging directory will log a warning.
+                mock_log.warning.assert_called_once_with(
+                    'Import methods are enabled but staging directory '
+                    '%(path)s does not exist; Imports will fail!',
+                    {'path': '/tmp/staging/'})
+
 
 class TestHelpers(test_utils.BaseTestCase):
 
