@@ -21,7 +21,9 @@ import warnings
 import fixtures as pyfixtures
 from openstack.identity.v3 import endpoint
 from openstack.identity.v3 import limit as klimit
+from oslo_db import warning as oslo_db_warning
 from oslo_limit import limit
+from sqlalchemy import exc as sqla_exc
 
 _TRUE_VALUES = ('True', 'true', '1', 'yes')
 
@@ -120,6 +122,9 @@ class WarningsFixture(pyfixtures.Fixture):
 
     def setUp(self):
         super(WarningsFixture, self).setUp()
+
+        self._original_warning_filters = warnings.filters[:]
+
         # NOTE(sdague): Make deprecation warnings only happen once. Otherwise
         # this gets kind of crazy given the way that upstream python libs use
         # this.
@@ -138,7 +143,62 @@ class WarningsFixture(pyfixtures.Fixture):
         warnings.filterwarnings(
             'error', message="Property '.*' has moved to '.*'")
 
-        self.addCleanup(warnings.resetwarnings)
+        # Don't warn for our own deprecation warnings
+
+        warnings.filterwarnings(
+            'ignore',
+            module='glance',
+            category=DeprecationWarning,
+        )
+
+        # Disable deprecation warning for oslo.db's EngineFacade. We *really*
+        # need to get off this but it's not happening while sqlalchemy 2.0
+        # stuff is ongoing
+
+        warnings.filterwarnings(
+            'ignore',
+            category=oslo_db_warning.OsloDBDeprecationWarning,
+            message='EngineFacade is deprecated',
+        )
+
+        # Enable deprecation warnings for glance itself to capture upcoming
+        # SQLAlchemy changes
+
+        warnings.filterwarnings(
+            'ignore',
+            category=sqla_exc.SADeprecationWarning,
+        )
+
+        warnings.filterwarnings(
+            'error',
+            module='glance',
+            category=sqla_exc.SADeprecationWarning,
+        )
+
+        # Enable general SQLAlchemy warnings also to ensure we're not doing
+        # silly stuff. It's possible that we'll need to filter things out here
+        # with future SQLAlchemy versions, but that's a good thing
+
+        warnings.filterwarnings(
+            'error',
+            module='glance',
+            category=sqla_exc.SAWarning,
+        )
+
+        # ...but filter everything out until we get around to fixing them
+        # TODO(stephenfin): Fix all of these
+
+        warnings.filterwarnings(
+            'ignore',
+            module='glance',
+            category=sqla_exc.SAWarning,
+            message='Class DeleteFromSelect will not make use of SQL ',
+        )
+
+        self.addCleanup(self._reset_warning_filters)
+
+    def _reset_warning_filters(self):
+        warnings.filters[:] = self._original_warning_filters
 
 
 class KeystoneQuotaFixture(pyfixtures.Fixture):
