@@ -20,7 +20,9 @@ from unittest import mock
 import urllib
 
 from oslo_config import cfg
+from oslo_policy import policy
 
+from glance.async_.flows._internal_plugins import base_download
 from glance.common import exception
 from glance.common import store_utils
 from glance.common import wsgi
@@ -86,6 +88,14 @@ def get_fake_request(path='', method='POST', is_admin=False, user=USER1,
     return req
 
 
+def enforcer_from_rules(unparsed_rules):
+    rules = policy.Rules.from_dict(unparsed_rules)
+    enforcer = glance.api.policy.Enforcer(
+        suppress_deprecation_warnings=True)
+    enforcer.set_rules(rules, overwrite=True)
+    return enforcer
+
+
 def fake_get_size_from_backend(uri, context=None):
     return 1
 
@@ -373,3 +383,8 @@ class FakeTask(object):
     def fail(self, message):
         self.message = message
         self._status = 'failure'
+
+
+class FakeBaseDownloadPlugin(base_download.BaseDownload):
+    def execute(self):
+        pass
